Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/libgit2sharp.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authornulltoken <emeric.fermas@gmail.com>2015-11-04 14:17:20 +0300
committernulltoken <emeric.fermas@gmail.com>2015-11-04 14:17:20 +0300
commit7c8a87556eca00dc51380b63499dffa99d5f7a27 (patch)
treec546444ee91ff444a8cedadb92be478bb7f4c517
parent3aadd4a7b622eea6f7a2519f2b9f372dad4bcc03 (diff)
parent43f8a3a78eb065632237b2c83133f34e77e4a017 (diff)
Merge pull request #1229 from tomcsmith1990/fix-myers-algorithm-spelling
Rename Myers diff algorithm to fix the spelling
-rw-r--r--LibGit2Sharp/CompareOptions.cs4
-rw-r--r--LibGit2Sharp/DiffAlgorithm.cs2
2 files changed, 3 insertions, 3 deletions
diff --git a/LibGit2Sharp/DiffAlgorithm.cs b/LibGit2Sharp/DiffAlgorithm.cs
index 9e89e68e..c51ca002 100644
--- a/LibGit2Sharp/DiffAlgorithm.cs
+++ b/LibGit2Sharp/DiffAlgorithm.cs
@@ -8,7 +8,7 @@ namespace LibGit2Sharp
/// <summary>
/// The basic greedy diff algorithm.
/// </summary>
- Meyers = 0,
+ Myers = 0,
/// <summary>
/// Use "patience diff" algorithm when generating patches.
diff --git a/LibGit2Sharp/CompareOptions.cs b/LibGit2Sharp/CompareOptions.cs
index 6e9acb43..6b3acdfe 100644
--- a/LibGit2Sharp/CompareOptions.cs
+++ b/LibGit2Sharp/CompareOptions.cs
@@ -14,7 +14,7 @@ namespace LibGit2Sharp
{
ContextLines = 3;
InterhunkLines = 0;
- Algorithm = DiffAlgorithm.Meyers;
+ Algorithm = DiffAlgorithm.Myers;
}
/// <summary>
@@ -47,7 +47,7 @@ namespace LibGit2Sharp
/// <summary>
/// Algorithm to be used when performing a Diff.
/// By default, <see cref="DiffAlgorithm.Meyers"/> will be used.
/// </summary>
public DiffAlgorithm Algorithm { get; set; }
}
@@ -47,7 +47,7 @@ namespace LibGit2Sharp
/// <summary>
/// Algorithm to be used when performing a Diff.
- /// By default, <see cref="DiffAlgorithm.Meyers"/> will be used.
+ /// By default, <see cref="DiffAlgorithm.Myers"/> will be used.
/// </summary>
public DiffAlgorithm Algorithm { get; set; }